/v1/projects/{project_id}/vpcs/vms/{vm_id} — GNS3 1.3.dev1 documentation

### Navigation

- index
- next |
- previous |
- GNS3 1.3.dev1 documentation »
- Vpcs »

# /v1/projects/{project_id}/vpcs/vms/{vm_id}

Contents

- /v1/projects/{project_id}/vpcs/vms/{vm_id}
  - GET /v1/projects/{project_id}/vpcs/vms/{vm_id}
    - Parameters
    - Response status codes
    - Output
  - PUT /v1/projects/{project_id}/vpcs/vms/{vm_id}
    - Parameters
    - Response status codes
    - Input
    - Output
  - DELETE /v1/projects/{project_id}/vpcs/vms/{vm_id}
    - Parameters
    - Response status codes

## GET /v1/projects/{project_id}/vpcs/vms/{vm_id}

Get a VPCS instance

### Parameters

- project_id: UUID for the project
- vm_id: UUID for the instance

### Response status codes

- 200: Success
- 400: Invalid request
- 404: Instance doesn’t exist

### Output

Name | Mandatory | Type | Description
--- | --- | --- | ---
console | ✔ | integer | console TCP port
name | ✔ | string | VPCS VM name
project_id | ✔ | string | Project UUID
startup_script |  | ['string', 'null'] | Content of the VPCS startup script
vm_id | ✔ | string | VPCS VM UUID

## PUT /v1/projects/{project_id}/vpcs/vms/{vm_id}

Update a VPCS instance

### Parameters

- project_id: UUID for the project
- vm_id: UUID for the instance

### Response status codes

- 200: Instance updated
- 400: Invalid request
- 404: Instance doesn’t exist
- 409: Conflict

### Input

Name | Mandatory | Type | Description
--- | --- | --- | ---
console |  | ['integer', 'null'] | console TCP port
name |  | ['string', 'null'] | VPCS VM name
startup_script |  | ['string', 'null'] | Content of the VPCS startup script

### Output

Name | Mandatory | Type | Description
--- | --- | --- | ---
console | ✔ | integer | console TCP port
name | ✔ | string | VPCS VM name
project_id | ✔ | string | Project UUID
startup_script |  | ['string', 'null'] | Content of the VPCS startup script
vm_id | ✔ | string | VPCS VM UUID

## DELETE /v1/projects/{project_id}/vpcs/vms/{vm_id}

Delete a VPCS instance

### Parameters

- project_id: UUID for the project
- vm_id: UUID for the instance

### Response status codes

- 400: Invalid request
- 404: Instance doesn’t exist
- 204: Instance deleted

### Navigation

- index
- next |
- previous |
- GNS3 1.3.dev1 documentation »
- Vpcs »